==> opennms-asterisk-1.7.3-sources.jar: org/opennms/netmgt/asterisk/utils/AsteriskOriginatorException.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc. All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Modifications:
 * 
 * 2009 Jan 17: Created file. - jeffg@opennms.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 *      OpenNMS Licensing <license@opennms.org>
 *      http://www.opennms.org/
 *      http://www.opennms.com/
 */

package org.opennms.netmgt.asterisk.utils;

/**
 * @author jeffg
 *
 */
public class AsteriskOriginatorException extends Exception {
    public AsteriskOriginatorException() {
        super();
    }

    public AsteriskOriginatorException(String message) {
        super(message);
    }

    public AsteriskOriginatorException(String message, Throwable cause) {
        super(message, cause);
    }

    public AsteriskOriginatorException(Throwable cause) {
        super(cause);
    }
}

==> opennms-asterisk-1.9.1-sources.jar: org/opennms/netmgt/asterisk/utils/AsteriskOriginatorException.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc. All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Modifications:
 * 
 * 2009 Jan 17: Created file. - jeffg@opennms.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 *      OpenNMS Licensing <license@opennms.org>
 *      http://www.opennms.org/
 *      http://www.opennms.com/
 */

package org.opennms.netmgt.asterisk.utils;

/**
 * <p>AsteriskOriginatorException class.</p>
 *
 * @author jeffg
 * @version $Id: $
 */
public class AsteriskOriginatorException extends Exception {
    private static final long serialVersionUID = 1L;

    /**
     * <p>Constructor for AsteriskOriginatorException.</p>
     */
    public AsteriskOriginatorException() {
        super();
    }

    /**
     * <p>Constructor for AsteriskOriginatorException.</p>
     *
     * @param message a {@link java.lang.String} object.
     */
    public AsteriskOriginatorException(String message) {
        super(message);
    }

    /**
     * <p>Constructor for AsteriskOriginatorException.</p>
     *
     * @param message a {@link java.lang.String} object.
     * @param cause a {@link java.lang.Throwable} object.
     */
    public AsteriskOriginatorException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * <p>Constructor for AsteriskOriginatorException.</p>
     *
     * @param cause a {@link java.lang.Throwable} object.
     */
    public AsteriskOriginatorException(Throwable cause) {
        super(cause);
    }
}
